@@ -1,21 +1,17 @@
 /*
- * ModSecurity for Apache 2.x, http://www.modsecurity.org/
- * Copyright (c) 2004-2010 Trustwave Holdings, Inc. (http://www.trustwave.com/)
- *
- * This product is released under the terms of the General Public Licence,
- * version 2 (GPLv2). Please refer to the file LICENSE (included with this
- * distribution) which contains the complete text of the licence.
- *
- * There are special exceptions to the terms and conditions of the GPL
- * as it is applied to this software. View the full text of the exception in
- * file MODSECURITY_LICENSING_EXCEPTION in the directory of this software
- * distribution.
- *
- * If any of the files related to licensing are missing or if you have any
- * other questions related to licensing please contact Trustwave Holdings, Inc.
- * directly using the email address support@trustwave.com.
- *
- */
+* ModSecurity for Apache 2.x, http://www.modsecurity.org/
+* Copyright (c) 2004-2011 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+*
+* You may not use this file except in compliance with
+* the License.  You may obtain a copy of the License at
+*
+*     http://www.apache.org/licenses/LICENSE-2.0
+*
+* If any of the files related to licensing are missing or if you have any
+* other questions related to licensing please contact Trustwave Holdings, Inc.
+* directly using the email address security@modsecurity.org.
+*/
+
 #if defined(WITH_LUA)
 
 #include "msc_lua.h"
@@ -100,7 +96,7 @@ char *lua_compile(msc_script **script, const char *filename, apr_pool_t *pool) {
     /* Find script. */
     if (luaL_loadfile(L, filename)) {
         return apr_psprintf(pool, "ModSecurity: Failed to compile script %s: %s",
-                filename, lua_tostring(L, -1));
+            filename, lua_tostring(L, -1));
     }
 
     /* Dump the script into binary form. */
@@ -234,7 +230,7 @@ static int l_getvar(lua_State *L) {
 
     /* Resolve variable. */
     var = msre_create_var_ex(msr->msc_rule_mptmp, msr->modsecurity->msre,
-            varname, param, msr, &my_error_msg);
+        varname, param, msr, &my_error_msg);
 
     if (var == NULL) {
         msr_log(msr, 1, "%s", my_error_msg);
@@ -303,7 +299,7 @@ static int l_getvars(lua_State *L) {
 
     /* Resolve variable. */
     vartemplate = msre_create_var_ex(msr->msc_rule_mptmp, msr->modsecurity->msre,
-            varname, param, msr, &my_error_msg);
+        varname, param, msr, &my_error_msg);
 
     if (vartemplate == NULL) {
         msr_log(msr, 1, "%s", my_error_msg);
@@ -365,7 +361,6 @@ static int l_setvar(lua_State *L) {
         msr_log(msr, 8, "m.setvar: Failed m.setvar funtion must has 2 arguments");
         return -1;
     }
-
     var_value = luaL_checkstring (L, 2);
     var_name = luaL_checkstring (L, 1);
 
@@ -424,22 +419,15 @@ int lua_execute(msc_script *script, char *param, modsec_rec *msr, msre_rule *rul
         lua_setglobal(L, "__rule");
     }
 
-    //lua_pushcfunction(L, l_setvar);
-    //lua_setglobal(L, "mysetvar");
-
     /* Register functions. */
     luaL_register(L, "m", mylib);
 
     rc = lua_restore(L, script);
     if (rc) {
         *error_msg = apr_psprintf(msr->mp, "Lua: Failed to restore script with %i.", rc);
-
-        if (msr->txcfg->debuglog_level >= 8) {
-            msr_log(msr, 8, "Lua: Failed to restore script with: %d",rc);
-        }
-
         return -1;
     }
+
     /* Execute the chunk so that the functions are defined. */
     lua_pcall(L, 0, 0, 0);
 
@@ -452,13 +440,7 @@ int lua_execute(msc_script *script, char *param, modsec_rec *msr, msre_rule *rul
     }
 
     if (lua_pcall(L, ((param != NULL) ? 1 : 0), 1, 0)) {
-
         *error_msg = apr_psprintf(msr->mp, "Lua: Script execution failed: %s", lua_tostring(L, -1));
-
-        if (msr->txcfg->debuglog_level >= 8) {
-            msr_log(msr, 8, "Lua: Script execution failed: %s", lua_tostring(L, -1));
-        }
-
         return -1;
     }
 
@@ -475,7 +457,7 @@ int lua_execute(msc_script *script, char *param, modsec_rec *msr, msre_rule *rul
     /* Returns status code to caller. */
     if (msr->txcfg->debuglog_level >= 8) {
         msr_log(msr, 8, "Lua: Script completed in %" APR_TIME_T_FMT " usec, returning: %s.",
-                (apr_time_now() - time_before), *error_msg);
+            (apr_time_now() - time_before), *error_msg);
     }
 
     return ((*error_msg != NULL) ? RULE_MATCH : RULE_NO_MATCH);
