@@ -419,28 +419,48 @@ char *file_dirname(apr_pool_t *p, const char *filename) {
 /**
  *
  */
+int sql_hex2bytes_inplace(unsigned char *data, int len) {
+    unsigned char *d, *begin = data;
+
+    if ((data == NULL)||(len == 0)) return 0;
+
+    for( d = data; *data; *d++ = *data++) {
+        if ( *data != '0' ) continue;
+        if ( tolower(*++data) != 'x' ) {
+            data--;
+            continue;
+        }
+
+        data++;
+
+        // Do we need to keep "0x" if no hexa after?
+        if ( !VALID_HEX(data[0]) || !VALID_HEX(data[1]) ) {
+            data-=2;
+            continue;
+        }
+
+        while ( VALID_HEX(data[0]) && VALID_HEX(data[1]) )  {
+            *d++ = x2c(data);
+            data += 2;
+        }
+    }
+
+    *d = '\0';
+    return strlen(begin);
+}
+
+/**
+ *
+ *
+ */
 int hex2bytes_inplace(unsigned char *data, int len) {
     unsigned char *d = data;
-    char print = 0;
     int i, count = 0;
 
     if ((data == NULL)||(len == 0)) return 0;
 
-    for(i = 0; i <= len - 1; i++) {
-        if(VALID_HEX(data[i]) && VALID_HEX(data[i+1]))  {
-            print = data[i];
-            if(print > 0x31 && print < 0x38)    {
-                *d++ = x2c(&data[i]);
-                i++;
-            } else {
-                *d++ = data[i];
-                *d++ = data[i+1];
-                i++;
-                count++;
-            }
-        } else  {
-            *d++ = data[i];
-        }
+    for(i = 0; i <= len - 2; i += 2) {
+        *d++ = x2c(&data[i]);
         count++;
     }
     *d = '\0';
@@ -600,7 +620,7 @@ char *current_logtime(apr_pool_t *mp) {
     apr_strftime(tstr, &len, 80, "%d/%b/%Y:%H:%M:%S ", &t);
     apr_snprintf(tstr + strlen(tstr), 80 - strlen(tstr), "%c%.2d%.2d",
             t.tm_gmtoff < 0 ? '-' : '+',
-            t.tm_gmtoff / (60 * 60), t.tm_gmtoff % (60 * 60));
+            t.tm_gmtoff / (60 * 60), (t.tm_gmtoff / 60) % 60);
     return apr_pstrdup(mp, tstr);
 }
 
